==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Překročen časový limit pro ověření se</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk je zaneprázdněn, nyní ho proto nelze odpojit</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk je zaneprázdněn, nyní ho proto nelze vysunout</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Zařízení je něčím využíváno, proto ho nyní není možné vysunout</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Zařízení je něčím využíváno, proto ho není možné nyní odebrat</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 svazek</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>Správce souborů</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Zařízení nebylo bezpečně odebráno</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Příště klepněte na „Bezpečně odebrat“ a až pak odpojte</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Zařízení je něčím využíváno, proto ho nyní není možné vysunout</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Zařízení je něčím využíváno, proto ho není možné nyní odebrat</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Zařízení se nedaří odpojit</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je připojený (mount) uživatelem „%1“ – vy ho odpojit nemůžete.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nedaří se nalézt připojené zařízení</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disky</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Vysunout vše</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Zařízení je možné bezpečně odebrat</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Přístup odepřen</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nemáte oprávnění pro přistupování k této složce</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Překročen časový limit pro ověření se</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk je zaneprázdněn, nyní ho proto nelze odpojit</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk je zaneprázdněn, nyní ho proto nelze vysunout</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Zařízení je něčím využíváno, proto ho nyní není možné vysunout</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Zařízení je něčím využíváno, proto ho není možné nyní odebrat</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 svazek</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>Správce souborů</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Zařízení nebylo bezpečně odebráno</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Příště klepněte na „Bezpečně odebrat“, a až pak odpojte</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Zařízení se nedaří odpojit</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je připojený (mount) uživatelem „%1“ – vy ho odpojit nemůžete.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nedaří se nalézt připojené zařízení</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disky</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Vysunout vše</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Zařízení je možné bezpečně odebrat</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Přístup odepřen</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nemáte oprávnění pro přistupování k této složce</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Prohledává se zařízení. Zastavit?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Zastavit</translation>
    </message>
</context>
</TS>
